@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 1018 2008-09-17 10:19:22Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 1112 2008-10-24 03:15:05Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -71,7 +71,7 @@ class BaseFrameContainer
 
 		// ページ作成開始
 		// セッション変数読み込み
-		$gPageManager->start($request);
+		$gPageManager->startPage($request);
 		
 		if (!defined('M3_STATE_IN_INSTALL')){		// インストールモード以外のとき
 			// ############## ユーザごとの設定の読み込み ###################
@@ -237,38 +237,38 @@ class BaseFrameContainer
 
 			// サブクラスの後処理の呼び出し
 			$this->_postBuffer($request);
-		
+	
 			// 現在の出力内容を取得し、一旦内容をクリア
 			$srcContents = ob_get_contents();
 			ob_clean();
-			
+		
 			// 遅延実行ウィジェットの出力を埋め込む
 			$destContents = $gPageManager->lateLaunchWidget($request, $srcContents);
-			
+		
 			// 携帯インターフェイスのときのときは、手動変換後、バイナリコード(絵文字等)を埋め込む
 			if ($gEnvManager->getIsMobile()){
 				// コンテンツ変換メソッドがある場合は実行
 				if (method_exists($this, '_convContents')){		
 					$destContents = mb_convert_encoding($destContents, $mobileEncoding, M3_ENCODING);		// 出力するコードに変換
 				}
-				
+			
 				// 絵文字埋め込み処理
 				$destContents = $this->_convContents($destContents);
-				
+			
 				// ページ作成終了処理(HTTPヘッダ出力)
-				$destContents .= $gPageManager->end($request, true/*出力を取得*/);		// 最終HTMLを追加
-				
+				$destContents .= $gPageManager->endPage($request, true/*出力を取得*/);		// 最終HTMLを追加
+			
 				// バッファを破棄
 				ob_end_flush();
-				
+			
 				// クライアントにデータを送信
 				echo $destContents;
 			} else {
 				echo $destContents;
-			
-				// ページ作成終了処理(HTTPヘッダ出力)
-				$gPageManager->end($request);
 		
+				// ページ作成終了処理(HTTPヘッダ出力)
+				$gPageManager->endPage($request);
+	
 				// mb_http_outputで設定したエンコーディングに変換して、バッファ内容を送信(クライアントへの送信完了)
 				ob_end_flush();
 			}
@@ -358,7 +358,7 @@ class BaseFrameContainer
 			}
 			
 			// ページ作成終了処理(HTTPヘッダ出力)
-			$gPageManager->end($request);
+			$gPageManager->endPage($request);
 			
 			// バッファ内容を送信(クライアントへの送信完了)
 			ob_end_flush();
@@ -538,7 +538,7 @@ class BaseFrameContainer
 		echo $destContents;
 		
 		// ページ作成終了処理(HTTPヘッダ出力)
-		$gPageManager->end($request);
+		$gPageManager->endPage($request);
 	
 		// バッファ内容を送信(クライアントへの送信完了)
 		ob_end_flush();
