@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 909 2008-08-12 07:23:06Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 974 2008-09-03 04:16:18Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -48,6 +48,8 @@ class BaseWidgetContainer
 	 */
 	function process($request)
 	{
+		global $gPageManager;
+			
 		// ウィジェット単位のアクセス制御
 		if (method_exists($this, '_checkAccess')){
 			// アクセス不可のときはここで終了
@@ -84,6 +86,21 @@ class BaseWidgetContainer
 			// 各ウィジェットごとのテンプレート処理、テンプレートを使用しないときは出力処理(Ajax等)
 			if (method_exists($this, '_postAssign')) $this->_postAssign($request, $param);
 			
+			// 各ウィジェットごとのCSSを取得し、ヘッダに設定
+			if (method_exists($this, '_addCssData')){
+				$css = $this->_addCssData($request, $param);
+				
+				// ヘッダにCSSを追加
+				if (!empty($css)) $gPageManager->addHeadCss($css);
+			}
+			// 各ウィジェットごとのJavascriptを取得し、ヘッダに設定
+			if (method_exists($this, '_addScriptData')){
+				$script = $this->_addScriptData($request, $param);
+				
+				// ヘッダにJavascriptを追加
+				if (!empty($script)) $gPageManager->addHeadScript($script);
+			}
+			
 			if ($templateFile != ''){
 				// エラーメッセージ出力
 				self::displayMsg();
@@ -154,7 +171,34 @@ class BaseWidgetContainer
 	function __parse()
 	{
 		echo $this->tmpl->getParsedTemplate('_widget');
-		//echo $this->tmpl->getParsedTemplate();
+	}
+	/**
+	 * patTemplateを使用した汎用データ変換処理
+	 *
+	 * ウィジェットのテンプレートディレクトリ内のテンプレートファイルを読み込みデータ変換後、文字列を返す。
+	 *
+	 * @param string $filename		テンプレートファイル名
+	 * @param function $callback	コールバック関数。「callback($tmpl) $tmpl=テンプレートオブジェクト」の形式で呼ばれる。
+	 * @param string $templateName	テンプレート名(デフォルトは「_tmpl」)
+	 * @return string				変換後データ
+	 */
+	function getParsedTemplateData($filename, $callback, $templateName = '_tmpl')
+	{
+		global $gEnvManager;
+		
+		// テンプレートオブジェクト作成
+		$tmpl = new PatTemplate();
+		
+		// テンプレート読み込みディレクトリを設定
+		$tmpl->setRoot($gEnvManager->getCurrentWidgetTemplatePath());
+		
+		// テンプレートファイルを設定
+		$tmpl->readTemplatesFromFile($filename);
+		
+		// コールバック関数を呼び出す
+		if (is_callable($callback)) call_user_func($callback, $tmpl);
+		
+		return $tmpl->getParsedTemplate($templateName);
 	}
 	/**
 	 * 表示用文字列に変換
