@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseDb.php 1001 2008-09-11 15:53:23Z fishbone $
+ * @version    SVN: $Id: baseDb.php 1054 2008-10-02 09:51:56Z fishbone $
  * @link       http://www.magic3.org
  */
 class BaseDb
@@ -448,7 +448,7 @@ class BaseDb
 	 * テキストデータをクエリーの実行行単位に解析
 	 *
 	 * @param  string $sql		解析を行うテキストデータ
-	 * @param  bool   $ret		クエリー行の配列
+	 * @param  array  $ret		クエリー行の配列
 	 * @return bool				true=正常終了、false=異常終了
 	 */
 	function _splitSql(&$ret, $sql)
@@ -1084,7 +1084,7 @@ class BaseDb
 					} else if (strncasecmp($cmd0, 'create', strlen('create')) == 0 && strncasecmp($cmd1, 'table', strlen('table')) == 0){		// create tableのとき
 						$wordsCount = count($words);
 						for ($j = 0; $j < $wordsCount; $j++){
-							if ($j < $wordsCount -1 && 
+							if ($j < $wordsCount -1 && 							// defaultに続く値を利用する
 								strncasecmp($words[$j], 'default', strlen('default')) == 0){
 								$trimValue = trim($words[$j+1], '\'"');
 								if ($trimValue == M3_TIMESTAMP_INIT_VALUE_MYSQL){		// 日時の初期値の修正、PostgreSQLでは「0000-00-00 00:00:00」で初期化できない
@@ -1100,6 +1100,17 @@ class BaseDb
 								$destStr .= $words[0] . ' SERIAL';
 								if ($words[$wordsCount -1] == ',') $destStr .= ',';
 								break;
+							} else if (strncasecmp($words[$j], 'text', strlen('text')) == 0){		// TEXTのとき
+								// DEFAULTが設定されていないかチェック
+								for ($k = 0; $k < $wordsCount; $k++){
+									if (strncasecmp($words[$k], 'default', strlen('default')) == 0) break;// DEFAULTが見つかった
+								}
+								if ($k < $wordsCount) continue;		// DEFAULTが設定されているので処理を行わない
+
+								$value = $words[$j];
+								$words[$j] = str_replace($value, $value . ' DEFAULT \'\'', $words[$j]);// 「DEFAULT ''」を追加する
+								$destStr .= ' ' . implode(' ', $words);
+								break;
 							}
 						}
 						if ($j == $wordsCount) $destStr .= ' ' . implode(' ', $words);
