@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 1064 2008-10-09 07:15:22Z fishbone $
+ * @version    SVN: $Id: envManager.php 1097 2008-10-21 11:50:36Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/core/version.php');	// システムバージョンクラス
@@ -343,6 +343,18 @@ class EnvManager
 	{
 		return M3_SYSTEM_ROOT_URL . '/' . M3_DIR_NAME_ADMIN . '/index.php';
 	}
+	/**
+	 * パーマネントリンク用の現在のページURLを取得
+	 *
+	 * @param bool $hasSubPage		サブページIDを必ず付加するかどうか。必ず付加しない場合はデフォルトページのとき省略
+	 * @return string				パーマネントリンクURL
+	 */
+	/*public function getCurrentPermanentPageUrl($hasSubPage=false)
+	{
+		$url = $this->getDefaultUrl();
+		if ($hasSubPage || $this->currentPageSubId != $this->defaultPageSubId) $url .= '?sub=' . $this->currentPageSubId;
+		return $url;
+	}*/
 	/**
 	 * ドキュメントルートからのリソース用ディレクトリへの相対パスを取得
 	 */
