@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: requestManager.php 1042 2008-09-26 11:42:42Z fishbone $
+ * @version    SVN: $Id: requestManager.php 1087 2008-10-18 10:11:29Z fishbone $
  * @link       http://www.magic3.org
  */
 class RequestManager
@@ -70,6 +70,14 @@ class RequestManager
 	{
 		return self::isPost($name) ? $_POST[$name] : '';
 	}
+	/**
+	 * POST値取得(トリミング(前後の空白削除)あり)
+	 */
+	public function trimValueOfPost($name)
+	{
+		$value = self::isPost($name) ? $_POST[$name] : '';
+		return $this->_trimValueOf($name, $value);
+	}
 	/**
 	 * GET値取得
 	 */
@@ -77,6 +85,14 @@ class RequestManager
 	{
 		return self::isGet($name) ? $_GET[$name] : '';
 	}
+	/**
+	 * GET値取得(トリミング(前後の空白削除)あり)
+	 */
+	public function trimValueOfGet($name)
+	{
+		$value = self::isGet($name) ? $_GET[$name] : '';
+		return $this->_trimValueOf($name, $value);
+	}
 	/**
 	 * POST,GETから値を取得
 	 *
@@ -103,15 +119,27 @@ class RequestManager
 	 * @return string			取得値
 	 */
 	public function trimValueOf($name, $default = '')
+	{
+		$srcValue = isset($_POST[$name]) ? $_POST[$name] : (isset($_GET[$name]) ? $_GET[$name] : $default);
+		return $this->_trimValueOf($name, $srcValue);
+	}
+	/**
+	 * トリミング(前後の空白削除)処理
+	 *
+	 * デフォルトでHTMLタグを取り除く
+	 *
+	 * @param string $name		キー値
+	 * @param string $value  	値
+	 * @return string			取得値
+	 */
+	public function _trimValueOf($name, $value)
 	{
 		global $gLogManager;
 		global $gEnvManager;
 		
-		$srcValue = isset($_POST[$name]) ? $_POST[$name] : (isset($_GET[$name]) ? $_GET[$name] : $default);
-
 		// トリムをかける
-		if (is_array($srcValue)){
-			$trimValue = array_map('trim', $srcValue);
+		if (is_array($value)){
+			$trimValue = array_map('trim', $value);
 
 			$destValue = array();
 			for ($i = 0; $i < count($trimValue); $i++){
@@ -121,15 +149,15 @@ class RequestManager
 					// ウィジェット内での処理の場合はウィジェットIDも出力
 					$widgetId = $gEnvManager->getCurrentWidgetId();// ウィジェットID
 					if (empty($widgetId)){
-						$gLogManager->warn(__METHOD__, 'POSTまたはGET値の異常データを検出: name=' . $name . ', value=[' . $srcValue[$i] . ']');
+						$gLogManager->warn(__METHOD__, 'POSTまたはGET値の異常データを検出: name=' . $name . ', value=[' . $value[$i] . ']');
 					} else {		// ウィジェットIDが設定されているとき
-						$gLogManager->warn(__METHOD__, 'POSTまたはGET値の異常データを検出: name=' . $name . ', value=[' . $srcValue[$i] . '], widgetid=' . $widgetId);
+						$gLogManager->warn(__METHOD__, 'POSTまたはGET値の異常データを検出: name=' . $name . ', value=[' . $value[$i] . '], widgetid=' . $widgetId);
 					}
 				}
 				$destValue[] = $stripValue;
 			}
 		} else {
-			$trimValue = trim($srcValue);
+			$trimValue = trim($value);
 			
 			// HTMLタグが含まれていた場合は、ログを残す
 			$destValue = $this->gpc_stripslashes($trimValue);
@@ -138,9 +166,9 @@ class RequestManager
 				// ウィジェット内での処理の場合はウィジェットIDも出力
 				$widgetId = $gEnvManager->getCurrentWidgetId();// ウィジェットID
 				if (empty($widgetId)){
-					$gLogManager->warn(__METHOD__, 'POSTまたはGET値の異常データを検出: name=' . $name . ', value=[' . $srcValue . ']');
+					$gLogManager->warn(__METHOD__, 'POSTまたはGET値の異常データを検出: name=' . $name . ', value=[' . $value . ']');
 				} else {		// ウィジェットIDが設定されているとき
-					$gLogManager->warn(__METHOD__, 'POSTまたはGET値の異常データを検出: name=' . $name . ', value=[' . $srcValue . '], widgetid=' . $widgetId);
+					$gLogManager->warn(__METHOD__, 'POSTまたはGET値の異常データを検出: name=' . $name . ', value=[' . $value . '], widgetid=' . $widgetId);
 				}
 			}
 		}
