@@ -461,9 +461,9 @@ CREATE TABLE _page_id (
     PRIMARY KEY  (pg_id, pg_type)
 ) TYPE=innodb;
 
--- ページオプションマスター
-DROP TABLE IF EXISTS _page_option;
-CREATE TABLE _page_option (
+-- ページ情報マスター
+DROP TABLE IF EXISTS _page_info;
+CREATE TABLE _page_info (
     pn_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
     pn_id                VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ページID
     pn_sub_id            VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- ページ補助ID
@@ -475,6 +475,8 @@ CREATE TABLE _page_option (
     pn_layout_id         VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- レイアウトID
     pn_meta_description  TEXT                                         NOT NULL,      -- METAタグ、ページ要約
     pn_meta_keywords     TEXT                                         NOT NULL,      -- METAタグ、検索用キーワード
+    pn_content_type      VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- メインコンテンツの種別(wiki=wikiコンテンツ)
+    pn_auth_type         INT            DEFAULT 0                     NOT NULL,      -- アクセス制御タイプ(0=制限なし、1=ログイン可能ユーザ、10=管理者のみ)
     pn_use_ssl           BOOLEAN        DEFAULT false                 NOT NULL,      -- SSLを使用するかどうか
     
     pn_checked_out       BOOLEAN        DEFAULT false                 NOT NULL,      -- チェックアウト中かどうか
