@@ -6,29 +6,31 @@
 -- システム設定マスター
 -- システムの動作に影響する設定を管理する
 INSERT INTO _system_config (sc_id,                         sc_value, sc_name,                sc_index) VALUES
-('system_name',                 'Magic3',     'システム名称',                    0),
-('db_version',                  '2008102501', 'DBバージョン',                    1),
-('server_id',                   '',           'サーバ識別用ID',                  2),
-('default_lang',                'ja',         'デフォルト言語',                  3),
-('multi_language',               '0',          '多言語対応',                      4),
-('csv_upload_encoding',         'SJIS-win',   'CSVアップロードエンコード',       5),
-('csv_download_encoding',       'SJIS-win',   'CSVダウンロードエンコード',       6),
-('csv_delim_code',              ',',          'CSV区切りコード',                 7),
-('csv_nl_code',                 '\r\n',       'CSV改行コード',                   8),
-('csv_file_suffix',             '.csv',       'CSVファイル拡張子',               9),
-('permit_init_system',          '0',          'システム初期化許可',              10),
-('permit_change_lang',          '1',          '処理言語変更許可',                11),
-('permit_detail_config',        '0',          'システム詳細設定許可',            12),
-('regenerate_session_id',       '0',          'セッションID毎回更新',            13),
-('script_cache_in_browser',     '1',          'ブラウザのスクリプトキャッシュ',  14),
-('site_in_public',              '1',          'サイト公開',                      15),
-('site_m_in_public',            '1',          '携帯サイト公開',                  16),
-('site_access_exception_ip',    '',           'サイトアクセス制御なしIP',        17),
-('toppage_image_path',          '',           'トップページ画像パス',            18),
-('mobile_encoding',             'SJIS',       '携帯用画面エンコード',            19),
-('install_dt',                  '',           'インストール日時',                20),
-('log_dir',                     '',           'ログ出力ディレクトリ',            21),
-('work_dir',                    '',           '作業用ディレクトリ',              22);
+('system_name',                 'Magic3',     'システム名称',                      0),
+('db_version',                  '2008110301', 'DBバージョン',                      1),
+('server_id',                   '',           'サーバ識別用ID',                    2),
+('default_lang',                'ja',         'デフォルト言語',                    3),
+('multi_language',               '0',          '多言語対応',                       4),
+('csv_upload_encoding',         'SJIS-win',   'CSVアップロードエンコード',         5),
+('csv_download_encoding',       'SJIS-win',   'CSVダウンロードエンコード',         6),
+('csv_delim_code',              ',',          'CSV区切りコード',                   7),
+('csv_nl_code',                 '\r\n',       'CSV改行コード',                     8),
+('csv_file_suffix',             '.csv',       'CSVファイル拡張子',                 9),
+('permit_init_system',          '0',          'システム初期化許可',                10),
+('permit_change_lang',          '1',          '処理言語変更許可',                  11),
+('permit_detail_config',        '0',          'システム詳細設定許可',              12),
+('regenerate_session_id',       '0',          'セッションID毎回更新',              13),
+('script_cache_in_browser',     '1',          'ブラウザのスクリプトキャッシュ',    14),
+('site_in_public',              '1',          'サイト公開',                        15),
+('site_m_in_public',            '1',          '携帯サイト公開',                    16),
+('site_access_exception_ip',    '',           'サイトアクセス制御なしIP',          17),
+('toppage_image_path',          '',           'トップページ画像パス',              18),
+('mobile_encoding',             'SJIS',       '携帯用画面エンコード',              19),
+('install_dt',                  '',           'インストール日時',                  20),
+('log_dir',                     '',           'ログ出力ディレクトリ',              21),
+('work_dir',                    '',           '作業用ディレクトリ',                22),
+('default_template',            '',           '一般画面用デフォルトテンプレート',  23),
+('admin_default_template',      '_admin',     '管理画面用デフォルトテンプレート',  24);
 
 -- 多言語対応文字列マスター
 INSERT INTO _language_string
@@ -146,6 +148,11 @@ INSERT INTO `_page_def` (`pd_id`,         `pd_sub_id`, `pd_position_id`, `pd_ind
 ('admin_index', 'content',        'main',         1,        'admin_main',       0,                   true,       false,       now()),
 ('admin_index', 'custom_admin',   'left',         1,        'release_info',       0,                   true,       false,       now());
 
+-- ページ情報マスター
+INSERT INTO _page_info
+(pn_id,   pn_sub_id, pn_content_type) VALUES
+('index', 'wiki',    'wiki');
+
 -- サイト定義マスター
 INSERT INTO `_site_def` (`sd_id`,              `sd_language_id`, `sd_value`,         `sd_create_dt`) VALUES
 ('head_description', 'ja',           '', now()),
