@@ -294,7 +294,10 @@ INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author,
 ('g_qrcode',     'Google QRコード',           '', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'Google APIを使ったQRコード表示。',         false,           false,       true,         true,        true,        false,               true,true,           0, now(), now());
 DELETE FROM _widgets WHERE wd_id = 'wiki_main';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_add_script_lib_a, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
-('wiki_main',          'Wiki - メイン',            '', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'Wikiを表示する。(実装中)', 'md5', 'md5',         false,           true,       true,         true,        true,        false,               false,true,               0, now(),    now());
+('wiki_main',          'Wiki - メイン',            '', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'Wikiを表示する。', 'md5', 'md5',         false,           true,       true,         true,        true,        false,               false,true,               0, now(),    now());
+DELETE FROM _widgets WHERE wd_id = 'default_login_box';
+INSERT INTO _widgets (wd_id, wd_name, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
+('default_login_box',         'デフォルトログイン',   '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'デフォルトのログイン用ボックス。', 'md5',        false,           false,       true,         true,        false,        false,               false,true,               100, now(),    now());
 
 -- ウィジェット情報(携帯用)
 DELETE FROM _widgets WHERE wd_id = 'm/sample';
@@ -329,7 +332,7 @@ INSERT INTO _widgets
 -- テンプレート情報
 TRUNCATE TABLE _templates;
 INSERT INTO _templates (tm_id,         tm_name,      tm_description, tm_default, tm_create_dt) 
-VALUES                 ('a6greyflash', 'a6greyflash','',             true,      now());
+VALUES                 ('a6greyflash', 'a6greyflash','',             false,      now());
 INSERT INTO _templates (tm_id,         tm_name,      tm_description, tm_default, tm_create_dt) 
 VALUES                 ('baki',        'baki',       '',             false,     now());
 INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
@@ -366,8 +369,14 @@ INSERT INTO _templates (tm_id,                    tm_name,                  tm_d
 VALUES                 ('ec_simple_w2',           'ec_simple_w2',           '',             false,      now());
 INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
 VALUES                 ('ec_simple_w3',           'ec_simple_w3',           '',             false,      now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
+VALUES                 ('simple_green1',          'simple_green1',           '',             false,      now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
+VALUES                 ('carnival',               'carnival',               '',             true,      now());
+INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_create_dt) 
+VALUES                 ('what',                   'what',                   '',             false,      now());
 INSERT INTO _templates (tm_id,                    tm_name,                  tm_description, tm_default, tm_mobile, tm_create_dt) 
-VALUES                 ('m/default',             'm/default',             '',             true,       true,      now());
+VALUES                 ('m/default',             'm/default',               '',             true,       true,      now());
 
 -- 基本テーブルの不要なデータを削除
 -- 画面定義
