@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTemplistWidgetContainer.php 948 2008-08-28 12:26:33Z fishbone $
+ * @version    SVN: $Id: admin_mainTemplistWidgetContainer.php 1168 2008-11-04 06:44:15Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -73,7 +73,7 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 		$act = $request->trimValueOf('act');
 		$selectedItemNo = $request->trimValueOf('no');		// 処理対象の項目番号
 		$userId = $gEnvManager->getCurrentUserId();
-		$serial = $request->trimValueOf('serial');		// シリアルNo
+		//$serial = $request->trimValueOf('serial');		// シリアルNo
 		$templateId = $request->trimValueOf('template');		// テンプレートID
 
 		if ($act == 'readnew'){		// テンプレート再読み込みのとき
@@ -118,32 +118,34 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 			// 変更可能値
 			$updateName = $request->trimValueOf('item' . $selectedItemNo . '_name');				// 名前
 			$updateIsDefault = ($request->trimValueOf('item' . $selectedItemNo . '_isdefault') == 'on') ? 1 : 0;		// デフォルトかどうか
-			$ret = $this->db->updateTemplate($serial, $updateName, $userId);
+			//$ret = $this->db->updateTemplate($serial, $updateName, $userId);
+			$ret = $this->db->updateTemplate($templateId, $updateName);
 			if ($ret){		// データ更新成功のとき
 				$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 			} else {
 				$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
 			}
 		} else if ($act == 'deleteline'){		// テンプレート削除のとき
-			if ($this->db->getTemplate($serial, $row)){
-				// テンプレートディレクトリ取得
-				$templateId = $row['tm_id'];
-				$templatePath = $gEnvManager->getTemplatesPath() . '/' . $templateId;
-			
-				// ディレクトリ削除
-				if ((is_dir($templatePath) && rmDirectory($templatePath)) || !is_dir($templatePath)){// 削除成功か、ディレクトリが存在しないとき
-					$ret = $this->db->deleteTemplate($serial, $userId);
-					if ($ret){		// データ更新成功のとき
-						$this->setMsg(self::MSG_GUIDANCE, 'テンプレートを削除しました');
-					} else {
-						$this->setMsg(self::MSG_APP_ERR, 'テンプレート削除に失敗しました');
-					}
+			//if ($this->db->getTemplate($serial, $row)){
+			// テンプレートディレクトリ取得
+			//$templateId = $row['tm_id'];
+			$templatePath = $gEnvManager->getTemplatesPath() . '/' . $templateId;
+		
+			// ディレクトリ削除
+			if ((is_dir($templatePath) && rmDirectory($templatePath)) || !is_dir($templatePath)){// 削除成功か、ディレクトリが存在しないとき
+				//$ret = $this->db->deleteTemplate($serial, $userId);
+				$ret = $this->db->deleteTemplate($templateId);
+				if ($ret){		// データ更新成功のとき
+					$this->setMsg(self::MSG_GUIDANCE, 'テンプレートを削除しました');
 				} else {
-					$this->setMsg(self::MSG_APP_ERR, 'テンプレートのディレクトリが削除できませんでした');
+					$this->setMsg(self::MSG_APP_ERR, 'テンプレート削除に失敗しました');
 				}
 			} else {
-				$this->setMsg(self::MSG_APP_ERR, '削除対象のテンプレートが見つかりません');
+				$this->setMsg(self::MSG_APP_ERR, 'テンプレートのディレクトリが削除できませんでした');
 			}
+			//} else {
+			//	$this->setMsg(self::MSG_APP_ERR, '削除対象のテンプレートが見つかりません');
+			//}
 		} else if ($act == 'upload'){		// ファイルアップロードの場合
 			// アップロードされたファイルか？セキュリティチェックする
 			if (is_uploaded_file($_FILES['upfile']['tmp_name'])) {
