@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainWidgetContainer.php 957 2008-08-29 09:30:07Z fishbone $
+ * @version    SVN: $Id: admin_mainWidgetContainer.php 1005 2008-09-13 06:39:46Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -68,6 +68,9 @@ class admin_mainWidgetContainer extends BaseWidgetContainer
 					} else if ($task == 'edittable' ||		// テーブルデータ編集一覧
 								$task == 'edittable_detail'){		// テーブルデータ編集詳細
 						$task = 'edittable';
+					} else if ($task == 'editmenu' ||		// メニュー編集
+								$task == 'editmenu_others'){		// メニュー編集その他
+						$task = 'editmenu';
 					}
 					
 					// オプション表示
