@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainDb.php 1001 2008-09-11 15:53:23Z fishbone $
+ * @version    SVN: $Id: admin_mainDb.php 1168 2008-11-04 06:44:15Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -1205,43 +1205,45 @@ class admin_mainDb extends BaseDb
 	/**
 	 * テンプレートの更新
 	 *
-	 * @param int $serial			シリアル番号
+	 * @param string $templateId	テンプレートID
 	 * @param string  $name			ウィジェット名
-	 * @param int $userId			ユーザID
 	 * @return						true=成功、false=失敗
 	 */
-	function updateTemplate($serial, $name, $userId)
+	function updateTemplate($templateId, $name)
 	{
+		global $gEnvManager;
+		
 		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
 				
 		// トランザクション開始
 		$this->startTransaction();
 		
-		// 指定のシリアルNoのレコードが削除状態でないかチェック
+		// 既存データを取得
 		$historyIndex = 0;		// 履歴番号
-		$queryStr  = 'select * from _templates ';
-		$queryStr .=   'where tm_serial = ? ';
-		$ret = $this->selectRecord($queryStr, array($serial), $row);
-		if ($ret){		// 既に登録レコードがあるとき
+		$queryStr = 'SELECT * FROM _templates ';
+		$queryStr .=  'WHERE tm_id = ? ';
+		$queryStr .=  'ORDER BY tm_history_index DESC ';
+		$ret = $this->selectRecord($queryStr, array($templateId), $row);
+		if ($ret){
 			if ($row['tm_deleted']){		// レコードが削除されていれば終了
 				$this->endTransaction();
 				return false;
+			} else {		// レコードが削除されていなければ、削除
+				// 古いレコードを削除
+				$queryStr  = 'UPDATE _templates ';
+				$queryStr .=   'SET tm_deleted = true, ';	// 削除
+				$queryStr .=     'tm_update_user_id = ?, ';
+				$queryStr .=     'tm_update_dt = ? ';
+				$queryStr .=   'WHERE tm_serial = ?';
+				$this->execStatement($queryStr, array($userId, $now, $row['tm_serial']));			
 			}
 			$historyIndex = $row['tm_history_index'] + 1;
-			$isDefault = intval($row['tm_default']);
-		} else {		// 存在しない場合は終了
+		} else {
 			$this->endTransaction();
 			return false;
 		}
-
-		// 古いレコードを削除
-		$queryStr  = 'UPDATE _templates ';
-		$queryStr .=   'SET tm_deleted = true, ';	// 削除
-		$queryStr .=     'tm_update_user_id = ?, ';
-		$queryStr .=     'tm_update_dt = ? ';
-		$queryStr .=   'WHERE tm_serial = ?';
-		$this->execStatement($queryStr, array($userId, $now, $serial));
-
+		
 		// 新規レコード追加
 		$queryStr  = 'INSERT INTO _templates (';
 		$queryStr .=   'tm_id, ';
@@ -1257,7 +1259,7 @@ class admin_mainDb extends BaseDb
 		$queryStr .=   '?, ';
 		$queryStr .=   '?, ';
 		$queryStr .=   '?)';
-		$this->execStatement($queryStr, array($row['tm_id'], $historyIndex, $name, $isDefault, $userId, $now));
+		$this->execStatement($queryStr, array($row['tm_id'], $historyIndex, $name, intval($row['tm_default']), $userId, $now));
 
 		// トランザクション確定
 		$ret = $this->endTransaction();
@@ -1266,34 +1268,35 @@ class admin_mainDb extends BaseDb
 	/**
 	 * テンプレートの削除
 	 *
-	 * @param string  $serial		シリアル番号
-	 * @param int $userId			ユーザID
+	 * @param string $templateId	テンプレートID
 	 * @return						true=成功、false=失敗
 	 */
-	function deleteTemplate($serial, $userId)
+	function deleteTemplate($templateId)
 	{
+		global $gEnvManager;
+		
 		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
 		
 		// トランザクション開始
 		$this->startTransaction();
 		
-		// 指定のシリアルNoのレコードが削除状態でないかチェック
-		$queryStr  = 'select * from _templates ';
-		$queryStr .=   'WHERE tm_serial = ? ';
-		$queryStr .=    'and tm_deleted = false';
-		$ret = $this->selectRecord($queryStr, array($serial), $row);
-		if (!$ret){		// 登録レコードがないとき
+		// 既存データを取得
+		$queryStr = 'SELECT * FROM _templates ';
+		$queryStr .=  'WHERE tm_deleted = false ';
+		$queryStr .=  'AND tm_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($templateId), $row);
+		if (!$ret){
 			$this->endTransaction();
 			return false;
 		}
-		
-		// 古いレコードを削除
+		// レコードを削除
 		$queryStr  = 'UPDATE _templates ';
 		$queryStr .=   'SET tm_deleted = true, ';	// 削除
 		$queryStr .=     'tm_update_user_id = ?, ';
 		$queryStr .=     'tm_update_dt = ? ';
 		$queryStr .=   'WHERE tm_serial = ?';
-		$this->execStatement($queryStr, array($userId, $now, $serial));
+		$this->execStatement($queryStr, array($userId, $now, $row['tm_serial']));
 		
 		// トランザクション確定
 		$ret = $this->endTransaction();
