@@ -11,7 +11,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: index.php 915 2008-08-14 08:30:00Z fishbone $
+ * @version    SVN: $Id: index.php 1020 2008-09-18 04:54:56Z fishbone $
  * @link       http://www.magic3.org
  */
 // 直接アクセスの防止
@@ -44,6 +44,7 @@ $HELP['userlist_del_btn']['title'] = '削除ボタン';
 $HELP['userlist_del_btn']['body'] = '選択されているユーザを削除します。<br>ユーザを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['userlist_ret_btn']['title'] = '戻るボタン';
 $HELP['userlist_ret_btn']['body'] = 'ユーザ一覧へ戻ります。';
+
 // ########## 画面作成 ##########
 $HELP['pagedef_page_id']['title'] = 'ページID';
 $HELP['pagedef_page_id']['body'] = 'ページを定義するためのIDです。IDはURLに付加されます。非公開項目は管理権限のない一般ユーザには公開されないページです。';
@@ -89,4 +90,37 @@ $HELP['edittable_del_btn']['title'] = '削除ボタン';
 $HELP['edittable_del_btn']['body'] = '選択されているレコードを削除します。<br>レコードを選択するには、一覧の左端のチェックボックスにチェックを入れます。';
 $HELP['edittable_ret_btn']['title'] = '戻るボタン';
 $HELP['edittable_ret_btn']['body'] = 'レコード一覧へ戻ります。';
+
+// ########## 管理メニュー編集編集 ##########
+$HELP['editmenu_config_others_btn']['title'] = 'その他ボタン';
+$HELP['editmenu_config_others_btn']['body'] = 'その他の設定を行います。';
+$HELP['editmenu_ret_btn']['title'] = '戻るボタン';
+$HELP['editmenu_ret_btn']['body'] = '管理メニュー編集へ戻ります。';
+$HELP['editmenu_top_image']['title'] = '管理メニュー画像';
+$HELP['editmenu_top_image']['body'] = '管理メニュー上に表示する画像です。[Magic3ルート]からの相対パスで指定します。';
+
+// ########## 置換文字列 ##########
+$HELP['usercustom_list']['title'] = '置換文字列一覧';
+$HELP['usercustom_list']['body'] = '置換文字列一覧です。置換文字列は、コンテンツテキストに埋め込み、コンテンツ表示時に自動変換される文字列です。';
+$HELP['usercustom_detail']['title'] = '置換文字列詳細';
+$HELP['usercustom_detail']['body'] = '置換文字列の情報を編集します。';
+$HELP['usercustom_new_btn']['title'] = '新規ボタン';
+$HELP['usercustom_new_btn']['body'] = '新規に置換文字列を追加します。';
+$HELP['usercustom_edit_btn']['title'] = '編集ボタン';
+$HELP['usercustom_edit_btn']['body'] = '選択されている置換文字列を編集します。<br />置換文字列を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['usercustom_del_btn']['title'] = '削除ボタン';
+$HELP['usercustom_del_btn']['body'] = '選択されている置換文字列を削除します。<br />置換文字列を選択するには、一覧の左端のチェックボックスにチェックを入れます。';
+$HELP['usercustom_ret_btn']['title'] = '戻るボタン';
+$HELP['usercustom_ret_btn']['body'] = '置換文字列一覧へ戻ります。';
+$HELP['usercustom_check']['title'] = '選択用チェックボックス';
+$HELP['usercustom_check']['body'] = '編集や削除を行う項目を選択します。';
+
+$HELP['usercustom_check2']['title'] = '選択用ラジオボタン';
+$HELP['usercustom_check2']['body'] = '編集を行う項目を選択します。新規追加する場合は「新規追加」項目を選択します。';
+$HELP['usercustom_key']['title'] = '置換キー文字列';
+$HELP['usercustom_key']['body'] = 'コンテンツテキストに埋め込むキー文字列です。コンテンツ表示時に、この文字列が「置換内容」に変換されます。';
+$HELP['usercustom_name']['title'] = '置換文字列名';
+$HELP['usercustom_name']['body'] = '置換文字列の管理上の名前です。';
+$HELP['usercustom_value']['title'] = '置換内容';
+$HELP['usercustom_value']['body'] = 'コンテンツ表示時に、コンテンツ上の置換キーから変換される文字列です。';
 ?>
