@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2007 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: default_contentWidgetContainer.php 217 2008-01-13 07:38:32Z fishbone $
+ * @version    SVN: $Id: default_contentWidgetContainer.php 734 2008-06-11 04:49:21Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -23,7 +23,7 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 	var $_contentCreated;	// コンテンツが取得できたかどうか
 	var $currentDay;		// 現在日
 	var $currentHour;		// 現在時間
-	const CONTENT_TYPE = 'ct';
+	const CONTENT_TYPE = 'ct';		// 参照数カウント用
 		
 	/**
 	 * コンストラクタ
@@ -110,7 +110,9 @@ class default_contentWidgetContainer extends BaseWidgetContainer
 		global $gTextConvManager;
 			
 		// ビューカウントを更新
-		$gAnalyzeManager->updateContentViewCount(self::CONTENT_TYPE, $fetchedRow['cn_serial'], $this->currentDay, $this->currentHour);
+		if (!$gEnvManager->isSystemAdmin()){		// システム管理者の場合はカウントしない
+			$gAnalyzeManager->updateContentViewCount(self::CONTENT_TYPE, $fetchedRow['cn_serial'], $this->currentDay, $this->currentHour);
+		}
 
 		// タイトルを設定
 		$title = $fetchedRow['cn_name'];
