@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_static_contentWidgetContainer.php 895 2008-08-10 07:34:05Z fishbone $
+ * @version    SVN: $Id: admin_static_contentWidgetContainer.php 962 2008-08-31 03:57:04Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -157,7 +157,7 @@ class admin_static_contentWidgetContainer extends BaseWidgetContainer
 				} else {
 					$this->setAppErrorMsg('データ追加に失敗しました');
 				}
-				$gPageManager->updateParentWindow();// 親ウィンドウを更新
+				$gPageManager->updateParentWindow($defSerial);// 親ウィンドウを更新
 			}
 		} else if ($act == 'update'){		// 項目更新の場合
 			// エラーなしの場合は、データを更新
@@ -186,12 +186,11 @@ class admin_static_contentWidgetContainer extends BaseWidgetContainer
 					
 					if (empty($defConfigId)){		// 画面定義の定義IDが設定されていないときは設定
 						$defConfigId = $this->configId;		// 定義定義IDを更新
-						$gPageManager->updateParentWindow();// 親ウィンドウを更新
 					}
 				} else {
 					$this->setAppErrorMsg('データ更新に失敗しました');
 				}
-				$gPageManager->updateParentWindow();// 親ウィンドウを更新
+				$gPageManager->updateParentWindow($defSerial);// 親ウィンドウを更新
 			}
 		}
 
