@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: wiki_mainWidgetContainer.php 1116 2008-10-24 11:40:55Z fishbone $
+ * @version    SVN: $Id: wiki_mainWidgetContainer.php 1164 2008-10-31 08:39:53Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -43,6 +43,9 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 	private $isPage;					// ページが存在するかどうか
 	private $isRead;					// ページ表示かどうか
 	private $isFreeze;					// ページが凍結中かどうか
+	private $relatedContents;			// 関連ページ表示用
+	private $attachContents;			// 添付ファイル表示用
+	private $lastModified;				// 最終更新表示用
 	const CONTENT_TYPE = 'wk';		// 参照数カウント用
 	
 	/**
@@ -93,18 +96,20 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 		global $vars;
 		
 		// 初期設定が完了していなときは、初期データ読み込み
-		WikiPage::readInitData();
+		$init = false;
+		if (!WikiPage::isInit()){		// 初期化未実行のとき
+			$init = WikiPage::readInitData();
+		}
 		
 		$this->langId = $gEnvManager->getCurrentLanguage();
 		$wikiLibDir = $gEnvManager->getCurrentWidgetLibPath();
 		
 		// Defaults
 		$notify = $trackback = $referer = 0;
-//global $gErrorManager;
-//$gErrorManager->writeDebug(__METHOD__, 'ini start');		// 時間計測用
+
 		// Load *.ini.php files and init PukiWiki
 		require($wikiLibDir . '/init.php');
-//$gErrorManager->writeDebug(__METHOD__, 'ini end');		// 時間計測用
+
 		// Load optional libraries
 		if ($notify) {
 			require($wikiLibDir . '/mail.php'); // Mail notification
@@ -114,7 +119,9 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 			// without functional reason now
 			require($wikiLibDir . '/trackback.php'); // TrackBack
 		}
-
+		// 初期データをインストールしたときは、リンク再構築
+		if ($init) links_init();
+		
 		// コマンド、プラグインが設定されていない場合は、クエリー文字列をInterWikiNameとする
 		$cmd = WikiParam::getCmd();
 		$plugin = WikiParam::getPlugin();
@@ -149,7 +156,8 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 			if (exist_plugin_action($plugin)) {
 				// Found and exec
 				$retvars = do_plugin_action($plugin);
-				if ($retvars === FALSE) exit; // Done
+				//if ($retvars === FALSE) exit; // Done
+				if ($retvars === FALSE) return;
 
 				if ($is_cmd) {
 					//$base = isset($vars['page'])  ? $vars['page']  : '';
@@ -166,13 +174,14 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 				$base = WikiConfig::getDefaultPage();
 			}
 		}
-		$title = htmlspecialchars(strip_bracket($base));
-		$pageLink  = make_search($base);
+		$headTitle = htmlspecialchars(strip_bracket($base));	// HTMLヘッダタイトル
+		$pageTitle  = make_search($base);
 		
 		// msgパラメータからタイトルを作成
-		if (isset($retvars['msg']) && $retvars['msg'] != '') {
-			$title = str_replace('$1', $title, $retvars['msg']);
-			$pageLink  = str_replace('$1', $pageLink,  $retvars['msg']);
+		if (isset($retvars['msg']) && $retvars['msg'] != '') {		// プラグイン実行の戻り値がある場合
+			$headTitle = str_replace('$1', $headTitle, $retvars['msg']);
+			//$pageTitle  = str_replace('$1', $pageTitle,  $retvars['msg']);
+			$pageTitle  = str_replace('$1', make_pagelink($base),  $retvars['msg']);// バックリンクではなくて通常のリンクに変更 by magic3
 		}
 		if (isset($retvars['body']) && $retvars['body'] != '') {
 			$body = $retvars['body'];
@@ -180,8 +189,8 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 			if ($base == '' || !is_page($base)){
 				//$base  = & $defaultpage;
 				$base = WikiConfig::getDefaultPage();
-				$title = htmlspecialchars(strip_bracket($base));
-				$pageLink  = make_search($base);
+				$headTitle = htmlspecialchars(strip_bracket($base));
+				$pageTitle  = make_search($base);		// 目的のページの場合はバックリンクを設定
 			}
 
 			// グローバル変数に値を格納
@@ -218,6 +227,7 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "content", $body);	// メインコンテンツ
 		$this->tmpl->addVar("_widget", "note", $notes);		// 追記
 		
+		// ##### ページ構成 #####
 		// ツールバー表示制御
 		if ($gEnvManager->isSystemAdmin() || WikiConfig::isShowToolbarForAllUser()){
 			$this->tmpl->setAttribute('show_toolbar', 'visibility', 'visible');
@@ -226,7 +236,7 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 		// タイトル表示制御
 		if (WikiConfig::isShowPageTitle()){
 			$this->tmpl->setAttribute('show_title', 'visibility', 'visible');
-			$this->tmpl->addVar("show_title", "title", make_search($base));	// タイトル
+			$this->tmpl->addVar("show_title", "title", $pageTitle);	// ページタイトル
 			
 			// Wikiページ表示のときは、リンク用URLを付加
 			if (WikiParam::getCmd() == 'read'){
@@ -238,6 +248,28 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 				$this->tmpl->addVar("show_title", "title_small", $permaLink);	// リンク用URL
 			}
 		}
+		// 添付ファイルの表示
+		if (WikiConfig::isShowPageAttachFiles() && !empty($this->attachContents)){
+			$this->tmpl->setAttribute('show_page_attach', 'visibility', 'visible');
+			$this->tmpl->addVar("show_page_attach", "content", $this->attachContents);
+		}
+		// ##### その他のページの情報 #####
+		$pageInfo = false;
+		// 最終更新の表示
+		if (WikiConfig::isShowPageLastModified() && !empty($this->lastModified)){
+			$this->tmpl->setAttribute('show_last_modified', 'visibility', 'visible');
+			$this->tmpl->addVar("show_last_modified", "content", $this->lastModified);
+			$pageInfo = true;
+		}
+		// 関連ページの表示
+		if (WikiConfig::isShowPageRelated() && !empty($this->relatedContents)){
+			$this->tmpl->setAttribute('show_page_related', 'visibility', 'visible');
+			$this->tmpl->addVar("show_page_related", "content", $this->relatedContents);
+			$pageInfo = true;
+		}
+		if ($pageInfo){
+			$this->tmpl->setAttribute('show_page_info', 'visibility', 'visible');
+		}
 	}
 	/**
 	 * 表示用データ作成
@@ -247,6 +279,9 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 	 */
 	function createViewData($body)
 	{
+		global $related_link;
+		global $attach_link;
+
 		$page = WikiParam::getPage();
 		$r_page = rawurlencode($page);
 		$script = WikiParam::getScript();
@@ -306,15 +341,16 @@ class wiki_mainWidgetContainer extends BaseWidgetContainer
 		$this->isFreeze = is_freeze($page);
 
 		// Last modification date (string) of the page
-		$lastmodified = $this->isRead ?  format_date(get_filetime($page)) .
-			' ' . get_pg_passage($page, FALSE) : '';
+		//$lastmodified = $this->isRead ?  format_date(get_filetime($page)) . ' ' . get_pg_passage($page, FALSE) : '';
+		$this->lastModified = $this->isRead ?  format_date(get_filetime($page)) . ' ' . get_pg_passage($page, FALSE) : '';
 
 		// List of attached files to the page
-		$attaches = ($attach_link && $this->isRead && exist_plugin_action('attach')) ?
-			attach_filelist() : '';
+		//$attaches = ($attach_link && $this->isRead && exist_plugin_action('attach')) ? attach_filelist() : '';
+		$this->attachContents = ($attach_link && $this->isRead && exist_plugin_action('attach')) ? attach_filelist() : '';
 
 		// List of related pages
-		$related  = ($related_link && $this->isRead) ? make_related($page) : '';
+		//$related  = ($related_link && $this->isRead) ? make_related($page) : '';
+		$this->relatedContents = ($related_link && $this->isRead) ? make_related($page) : '';
 
 		// List of footnotes
 		$footNote = WikiPage::getFootNote();
