@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: wikiParam.php 1086 2008-10-18 10:07:39Z fishbone $
+ * @version    SVN: $Id: wikiParam.php 1166 2008-11-01 09:36:07Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/wiki_mainDb.php');
@@ -286,7 +286,7 @@ class WikiParam
 	 * @param bool $encode		URLエンコードを行うかどうか
 	 * @return string			変換後文字列
 	 */
-	public static function convQuery($srcStr, $encode=true)
+	public static function convQuery($srcStr = '?', $encode = true)
 	{
 		$destStr = $srcStr;
 		
