@@ -10,11 +10,11 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: edit.inc.php 1139 2008-10-27 04:19:53Z fishbone $
+ * @version    SVN: $Id: edit.inc.php 1160 2008-10-30 04:48:00Z fishbone $
  * @link       http://www.magic3.org
  */
 // PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: edit.inc.php 1139 2008-10-27 04:19:53Z fishbone $
+// $Id: edit.inc.php 1160 2008-10-30 04:48:00Z fishbone $
 // Copyright (C) 2001-2006 PukiWiki Developers Team
 // License: GPL v2 or (at your option) any later version
 
@@ -288,8 +288,11 @@ function plugin_edit_write()
 	}
 
 	// NULL POSTING, OR removing existing page
-	if ($postdata == '') {
-		page_write($page, $postdata);
+	//if ($postdata == '') {
+	// スペースや改行のみのデータのときは、空データとしてページを削除
+	if (trim($postdata) == ''){
+		//page_write($page, $postdata);
+		page_write($page, '');
 		$retvars['msg' ] = $_title_deleted;
 		$retvars['body'] = str_replace('$1', htmlspecialchars($page), $_title_deleted);
 
